@@ -31,3 +31,9 @@ def main():
     else:
         cli = TooriClient(args.addr, args.port, args.filter, args.transports, args.key)
         cli.start()
+
+
+if __name__ == "__main__":
+    from toori.gui import gui_main
+
+    gui_main()
